@@ -1,3 +1,8 @@
+#' @include ml_clustering.R
+#' @include ml_model_helpers.R
+#' @include utils.R
+NULL
+
 #' Spark ML -- Gaussian Mixture clustering.
 #'
 #' This class performs expectation maximization for multivariate Gaussian Mixture Models (GMMs). A GMM represents a composite distribution of independent Gaussian distributions with associated "mixing" weights specifying each's contribution to the composite. Given a set of sample points, this class will maximize the log-likelihood for a mixture of k Gaussians, iterating until the log-likelihood changes by less than \code{tol}, or until it has reached the max number of iterations. While this process is generally guaranteed to converge, it is not guaranteed to find a global optimum.
