@@ -138,16 +138,22 @@ sdf_deserialize_column <- function(column, sc) {
 #' @param column The name of a column within \code{x}.
 #' @export
 sdf_read_column <- function(x, column) {
-  sc <- spark_connection(x)
+  UseMethod("sdf_read_column")
+}
+
+#' @export
+sdf_read_column.spark_jobj <- function(x, column) {
   sdf <- spark_dataframe(x)
-
-  col_df <- sdf %>%
-    invoke("select", column, list()) %>%
-    collect()
-
+  col_df <- invoke(sdf, "select", column, list())
+  col_df <- collect(col_df)
   col_df[[column]]
 }
 
+#' @export
+sdf_read_column.tbl_spark <- function(x, column) {
+  dplyr::pull(x, column)
+}
+
 #' Collect a Spark DataFrame into R.
 #'
 #' Collects a Spark dataframe into R.
