@@ -6,7 +6,8 @@ sparklyr_jar_spec_list <- function() {
     list(spark = "2.3.0", scala = "2.11"),
     list(spark = "2.4.0", scala = "2.11"),
     list(spark = "2.4.0", scala = "2.12"),
-    list(spark = "3.4.0", scala = "2.12", jar_name = "sparklyr-master-2.12.jar")
+    list(spark = "3.0.0", scala = "2.12"),
+    list(spark = "3.5.0", scala = "2.12", jar_name = "sparklyr-master-2.12.jar")
   )
 }
 
@@ -33,7 +34,6 @@ sparklyr_jar_verify_spark <- function(install = TRUE) {
 #' Given a set of \code{scala} source files, compile them
 #' into a Java Archive (\code{jar}).
 #'
-#' @param name The name to assign to the target \code{jar}.
 #' @param spark_home The path to the Spark sources to be used
 #'   alongside compilation.
 #' @param filter An optional function, used to filter out discovered \code{scala}
